==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/no.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E 'kl'. HH:mm",
    EHms => "E 'kl'. HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "dd.MM.y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L.",
    MEd => "E d.M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "'den' W. 'uken' 'i' MMMM",
    "MMMMW-count-other" => "'den' W. 'uken' 'i' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d.M.",
    Md => "d.M.",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'uke' w 'i' Y",
    "yw-count-other" => "'uke' w 'i' Y",
  },
  code => "no",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} 'kl'. {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  day_stand_alone_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_wide => [
    "f\N{U+00f8}r Kristus",
    "etter Kristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Norwegian",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  name => "Norwegian",
  native_language => "norsk",
  native_name => "norsk",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.37.tar.gz: DateTime-Locale-1.37/share/no.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E 'kl'. HH:mm",
    EHms => "E 'kl'. HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "dd.MM.y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L.",
    MEd => "E d.M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "'den' W. 'uken' 'i' MMMM",
    "MMMMW-count-other" => "'den' W. 'uken' 'i' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d.M.",
    Md => "d.M.",
    d => "d.",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'uke' w 'i' Y",
    "yw-count-other" => "'uke' w 'i' Y",
  },
  code => "no",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  day_stand_alone_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_wide => [
    "f\N{U+00f8}r Kristus",
    "etter Kristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Norwegian",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  name => "Norwegian",
  native_language => "norsk",
  native_name => "norsk",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
